@@ -71,11 +71,22 @@ except ImportError:
         from pathlib2 import Path
     except ImportError:
         Path = None
+
+try:
+    from scandir import scandir, walk
+except ImportError:
+    from os import scandir, walk
+
 try:
     import numpy
 except (ImportError, SyntaxError):
     numpy = None
 
+try:
+    from functools import reduce
+except (ImportError, SyntaxError):
+    pass
+
 __all__ = ('Counter', 'OrderedDict',
            'Enum', 'EnumMeta', 'unique',
            'ispyname', 'pytuple',
@@ -85,6 +96,8 @@ __all__ = ('Counter', 'OrderedDict',
            'HashableABC', 'SequenceABC', 'SizedABC',
            'cache_from_source',
            'lru_cache',
-           'Path', 'numpy')
+           'Path', 'scandir', 'walk',
+           'numpy',
+           'reduce')
 
 __dir__ = lambda: list(__all__)
\ No newline at end of file
