@@ -1,26 +1,20 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-import sys
+import sys, os
 import warnings
 
-# Unused clade-related stuff:
-# import re
-# from constants import DEBUG, SINGLETON_TYPES, Enum, unique
-# from constants import PY3, SEPARATOR_WIDTH, OrderedDict
-# from predicates import case_sort
-# from repl import print_separator
-
-from clu.constants import BUILTINS, λ, MAXINT
-from clu.constants import Counter, MutableMapping, NoDefault
-from clu.constants import ExportError, ExportWarning
-from clu.constants import lru_cache, pytuple
+from clu.constants.consts import λ, NoDefault, pytuple
+from clu.constants.exceptions import ExportError, ExportWarning
+from clu.constants.polyfills import MutableMapping, lru_cache
 
 def doctrim(docstring):
     """ This function is straight outta PEP257 -- q.v. `trim(…)`,
        “Handling Docstring Indentation” subsection sub.:
             https://www.python.org/dev/peps/pep-0257/#id18
     """
+    from clu.constants.consts import MAXINT
+    
     if not docstring:
         return ''
     # Convert tabs to spaces (following the normal Python rules)
@@ -50,6 +44,8 @@ def itermoduleids(module):
         tuples for all things comntained in a given module – q.v.
         `itermodule(…)` implementation supra.
     """
+    from clu.constants.consts import BUILTINS
+    
     keys = tuple(key for key in dir(module) \
                       if key not in BUILTINS)
     ids = (id(getattr(module, key)) for key in keys)
@@ -141,6 +137,38 @@ def determine_name(thing, name=None, try_repr=False):
     # up returning None:
     return thingname_search(thing)
 
+def path_to_dotpath(path):
+    """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
+        to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
+        would call a “quick and dirty” fashion.
+        
+        Issues a BadDotpathWarning if the converted path contains
+        dashes – I don’t quite know what to do about something
+        like that besides warn, so erm. There you go.
+    """
+    from clu.constants.consts import BASEPATH, QUALIFIER
+    from clu.constants.exceptions import BadDotpathWarning
+    
+    # Relativize the path to the BASEPATH,
+    # and replace slashes with dots:
+    relpath = os.path.relpath(path, start=BASEPATH)
+    dotpath = relpath.replace(os.path.sep, QUALIFIER)
+    
+    # Trim off any remaining “.py” suffixes,
+    # and extraneous dot-prefixes:
+    if dotpath.endswith('.py'):
+        dotpath = dotpath[:len(dotpath)-3]
+    while dotpath.startswith(QUALIFIER):
+        dotpath = dotpath[1:]
+    
+    # Warn before returning, if the converted path
+    # should contain dashes:
+    if '-' in dotpath:
+        warnings.warn("Dotpath contains dashes: “%s”" % dotpath,
+                      BadDotpathWarning, stacklevel=2)
+    
+    return dotpath
+
 def predicates_for_types(*types):
     """ For a list of types, return a list of “isinstance” predicates """
     predicates = []
@@ -151,16 +179,21 @@ def predicates_for_types(*types):
 class Exporter(MutableMapping):
     
     """ A class representing a list of things for a module to export. """
-    __slots__ = pytuple('exports', 'clades')
+    __slots__ = pytuple('exports') + ('path', 'dotpath')
     
-    def __init__(self, *args):
+    def __init__(self, *args, **kwargs):
         self.__exports__ = {}
-        self.__clades__ = Counter()
+        
+        if 'path' in kwargs:
+            self.path = kwargs.pop('path', None)
+            if self.path is not None:
+                self.dotpath = path_to_dotpath(self.path)
+            else:
+                self.dotpath = None
         
         for arg in args:
             if isinstance(arg, type(self)):
                 self.__exports__.update(arg.__exports__)
-                self.__clades__.update(arg.__clades__)
             else:
                 try:
                     d = dict(arg)
@@ -175,10 +208,6 @@ class Exporter(MutableMapping):
         out.update(self.__exports__)
         return out
     
-    def clade_histogram(self):
-        """ Return the histogram of clade counts. """
-        return Counter(self.__clades__)
-    
     def keys(self):
         """ Get a key view on the exported items dictionary. """
         return self.__exports__.keys()
@@ -199,6 +228,14 @@ class Exporter(MutableMapping):
             return self.__exports__.pop(key)
         return self.__exports__.pop(key, default)
     
+    def update(self, dictish=NoDefault, **updates):
+        """ Update the exporter with key/value pairs and/or an iterator;
+            q.v. `dict.update(…)` docstring supra.
+        """
+        if dictish is NoDefault:
+            return self.__exports__.update(**updates)
+        return self.__exports__.update(dictish, **updates)
+    
     messages = {
         'docstr'    : "Can’t set the docstring for thing “%s” of type %s:",
         'noname'    : "Can’t determine a name for lambda: 0x%0x"
@@ -292,13 +329,13 @@ class Exporter(MutableMapping):
         """
         return self.export
     
-    def __call__(self):
-        """ Exporter instances are callable, for use in `__all__` definitions """
+    def all_tuple(self):
+        """ For use in module `__all__` tuple definitions """
         return tuple(self.keys())
     
     def dir_function(self):
         """ Return a list containing the exported module names. """
-        return list(self.keys())
+        return lambda: list(self.keys())
     
     def all_and_dir(self):
         """ Assign a modules’ __all__ and __dir__ values, e.g.:
@@ -309,7 +346,7 @@ class Exporter(MutableMapping):
             all calls to `exporter.export(…)` (aka @export) have
             been made – q.v. the “decorator()” method supra.
         """
-        return self(), self.dir_function
+        return self.all_tuple(), self.dir_function()
     
     def dir_and_all(self):
         """ Assign a modules’ __dir__ and __all__ values, e.g.:
@@ -320,7 +357,7 @@ class Exporter(MutableMapping):
             all calls to `exporter.export(…)` (aka @export) have
             been made – q.v. the “decorator()” method supra.
         """
-        return self.dir_function, self() # OPPOSITE!
+        return self.dir_function(), self.all_tuple() # OPPOSITE!
     
     def cache_info(self):
         """ Shortcut to get the CacheInfo namedtuple from the
@@ -328,7 +365,6 @@ class Exporter(MutableMapping):
             which is used in last-resort name lookups made by
             `determine_name(…)` during `export(…)` calls.
         """
-        from clu.naming import thingname_search_by_id
         return thingname_search_by_id.cache_info()
     
     def __iter__(self):
@@ -370,7 +406,7 @@ class Exporter(MutableMapping):
         from clu.predicates import ismergeable
         if not ismergeable(operand):
             return NotImplemented
-        self.__exports__.update(operand.__exports__)
+        self.update(**getattr(operand, '__exports__', operand))
         return self
     
     def __or__(self, operand):
@@ -391,6 +427,8 @@ export = exporter.decorator()
 export(doctrim)
 export(thingname_search)
 export(determine_name)
+export(path_to_dotpath)
+export(predicates_for_types)
 export(sysmods,         name='sysmods',         doc="sysmods() → shortcut for reversed(tuple(frozenset(sys.modules.values()))) …OK? I know. It’s not my finest work, but it works.")
 
 # NO DOCS ALLOWED:
@@ -398,3 +436,17 @@ export(Exporter)        # hahaaaaa
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
+
+def test():
+    from pprint import pprint
+    print("» LOCALS:")
+    pprint(locals())
+    print()
+    
+    print("» GLOBALS:")
+    pprint(globals())
+    print()
+
+if __name__ == '__main__':
+    test()
+
