@@ -10,42 +10,28 @@ import os
 import re
 import shutil
 import sys
-
-try:
-    from scandir import scandir, walk
-except ImportError:
-    from os import scandir, walk
     
 from distutils.spawn import find_executable
 from functools import wraps
 from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 
-from clu.constants import DELETE_FLAG, ENCODING, PATH
-from clu.constants import lru_cache
-from clu.constants import ExecutionError, FilesystemError
+from clu.constants.consts import DELETE_FLAG, ENCODING, PATH
+from clu.constants.exceptions import ExecutionError, FilesystemError
+from clu.constants.polyfills import lru_cache, scandir, walk
 from clu.predicates import attr, allattrs
 from clu.sanitizer import utf8_encode
 from clu.typology import ispath, isvalidpath
 from .misc import masked_permissions
 from .misc import stringify, suffix_searcher, u8str
+from clu.exporting import Exporter
 
-__all__ = ('DEFAULT_PREFIX',
-           'DEFAULT_TIMEOUT',
-           'ExecutionError', 'FilesystemError',
-           'ensure_path_is_valid',
-           'script_path', 'which', 'back_tick',
-           'rm_rf', 'temporary',
-           'TemporaryName',
-           'Directory',
-           'cd', 'wd',
-           'TemporaryDirectory', 'Intermediate',
-           'NamedTemporaryFile')
-
-__dir__ = lambda: list(__all__)
+exporter = Exporter(path=__file__)
+export = exporter.decorator()
 
 DEFAULT_TIMEOUT = 60 # seconds
 DEFAULT_PREFIX = "yo-dogg-"
 
+@export
 def ensure_path_is_valid(pth):
     """ Raise an exception if we can’t write to the specified path """
     if not ispath(pth):
@@ -58,6 +44,7 @@ def ensure_path_is_valid(pth):
     if not os.path.isdir(parent_dir):
         raise FilesystemError("Directory doesn’t exist: %s" % parent_dir)
 
+@export
 def write_to_path(data, pth, relative_to=None, verbose=False):
     """ Write data to a new file using a context-managed handle """
     ensure_path_is_valid(pth)
@@ -71,6 +58,7 @@ def write_to_path(data, pth, relative_to=None, verbose=False):
                                           os.path.relpath(pth,
                                                           start=start)))
 
+@export
 def script_path():
     """ Return the path to the embedded scripts directory. """
     return os.path.join(
@@ -78,6 +66,7 @@ def script_path():
            os.path.dirname(
            os.path.dirname(__file__))), 'scripts')
 
+@export
 def which(binary_name, pathvar=None):
     """ Deduces the path corresponding to an executable name,
         as per the UNIX command `which`. Optionally takes an
@@ -89,6 +78,7 @@ def which(binary_name, pathvar=None):
 
 which.pathvar = PATH
 
+@export
 def back_tick(command,  as_str=True,
                        ret_err=False,
                      raise_err=None, **kwargs):
@@ -203,6 +193,7 @@ def back_tick(command,  as_str=True,
                (as_str and errors.decode(encoding) or errors)
     return (as_str and output.decode(encoding) or output)
 
+@export
 def rm_rf(pth):
     """ rm_rf() does what `rm -rf` does – so, for the love of fuck,
         BE FUCKING CAREFUL WITH IT.
@@ -228,6 +219,7 @@ def rm_rf(pth):
         pass
     return False
 
+@export
 def temporary(suffix='', prefix='', parent=None, **kwargs):
     """ Wrapper around `tempfile.mktemp()` that allows full overriding of the
         prefix and suffix by the caller -- that is to say, no random elements
@@ -394,6 +386,7 @@ def TemporaryNamedFile(tempth, mode='wb', buffer_size=-1, delete=True):
                 os.close(descriptor)
         raise FilesystemError(str(base_exception))
 
+@export
 class TemporaryName(collections.abc.Hashable,
                     contextlib.AbstractContextManager,
                     os.PathLike,
@@ -406,8 +399,10 @@ class TemporaryName(collections.abc.Hashable,
         Unless you say not to. Really it's your call dogg I could give AF
     """
     
-    fields = ('name', 'exists', 'mode',
-              'destroy', 'prefix', 'suffix', 'parent')
+    fields = ('name', 'exists', 'destroy',
+              'mode', 'binary_mode',
+              'prefix', 'suffix',
+              'parent')
     
     def __init__(self, prefix=None, suffix="tmp",
                        parent=None,
@@ -562,8 +557,9 @@ class TemporaryName(collections.abc.Hashable,
         if not destination:
             raise FilesystemError("Copying requires a place to which to copy")
         if self.exists:
-            if os.path.samefile(self._name, destination):
-                raise FilesystemError("Can’t copy across identical locations")
+            if os.path.exists(destination):
+                if os.path.samefile(self._name, destination):
+                    raise FilesystemError("Can’t copy to identical locations")
             return shutil.copy2(self._name, os.fspath(destination))
         return False
     
@@ -606,7 +602,7 @@ class TemporaryName(collections.abc.Hashable,
         return stringify(self, type(self).fields)
     
     def __repr__(self):
-        return stringify(self, type(self).fields)
+        return self.to_string()
     
     def __str__(self):
         if self.exists:
@@ -646,6 +642,7 @@ class TemporaryName(collections.abc.Hashable,
 non_dotfile_match = re.compile(r"^[^\.]").match
 non_dotfile_matcher = lambda p: non_dotfile_match(p.name)
 
+@export
 class Directory(collections.abc.Hashable,
                 collections.abc.Mapping,
                 collections.abc.Sized,
@@ -986,16 +983,15 @@ class Directory(collections.abc.Hashable,
         if zpth is None:
             raise FilesystemError("Need to specify a zip-archive file path")
         zpth = os.fspath(zpth)
-        if not zpth.lower().endswith(self.zip_suffix):
-            zpth += self.zip_suffix
-        if os.path.exists(zpth):
-            if os.path.isdir(zpth):
-                raise FilesystemError("Can't overwrite a directory: %s" % zpth)
-            raise FilesystemError("File path for zip-archive already exists")
+        zsuf = type(self).zip_suffix
+        if not zpth.lower().endswith(zsuf):
+            zpth += zsuf
         if not zmode:
             zmode = zipfile.ZIP_DEFLATED
+        ensure_path_is_valid(zpth)
         with TemporaryName(prefix="ziparchive-",
-                           suffix=self.zip_suffix[1:]) as ztmp:
+                           suffix=zsuf[1:],
+                           randomized=True) as ztmp:
             with zipfile.ZipFile(ztmp.name, "w", zmode) as ziphandle:
                 relparent = lambda p: os.path.relpath(p, os.fspath(self.parent()))
                 for root, dirs, files in self.walk(followlinks=True):
@@ -1005,7 +1001,7 @@ class Directory(collections.abc.Hashable,
                         if os.path.isfile(filepath): # regular files only
                             arcname = os.path.join(relparent(root), filename)
                             ziphandle.write(filepath, arcname) # add regular file
-            ztmp.copy(zpth)
+            assert ztmp.copy(zpth)
         return self.realpath(zpth)
     
     def symlink(self, destination, pth=None):
@@ -1032,7 +1028,7 @@ class Directory(collections.abc.Hashable,
         return stringify(self, type(self).fields)
     
     def __repr__(self):
-        return stringify(self, type(self).fields)
+        return self.to_string()
     
     def __str__(self):
         if self.exists:
@@ -1088,6 +1084,7 @@ class Directory(collections.abc.Hashable,
     def __call__(self, *args, **kwargs):
         return self
 
+@export
 class cd(Directory):
     
     def __init__(self, pth):
@@ -1095,6 +1092,7 @@ class cd(Directory):
         """
         super(cd, self).__init__(pth)
 
+@export
 class wd(Directory):
     
     def __init__(self):
@@ -1102,6 +1100,7 @@ class wd(Directory):
         """
         super(wd, self).__init__(pth=None)
 
+@export
 class TemporaryDirectory(Directory):
     
     """ It's funny how this code looks, like, 99 percent exactly like the above
@@ -1210,6 +1209,7 @@ class TemporaryDirectory(Directory):
             out &= self.close()
         return out
 
+@export
 class Intermediate(TemporaryDirectory, Directory):
     
     """ clu.fs.filesystem.Intermediate isn’t a class, per se – rather,
@@ -1234,6 +1234,7 @@ class Intermediate(TemporaryDirectory, Directory):
         """
         pass
 
+@export
 def NamedTemporaryFile(mode='w+b', buffer_size=-1,
                        suffix="tmp", prefix=DEFAULT_PREFIX,
                        directory=None,
@@ -1264,7 +1265,7 @@ def NamedTemporaryFile(mode='w+b', buffer_size=-1,
     
     (descriptor, name) = _mkstemp_inner(parent.name, prefix,
                                                      suffix, flags,
-                                               bytes(suffix), encoding=ENCODING)
+                                               bytes(suffix, encoding=ENCODING))
     try:
         filehandle = os.fdopen(descriptor, mode, buffer_size)
         return TemporaryFileWrapper(filehandle, name, delete)
@@ -1274,4 +1275,9 @@ def NamedTemporaryFile(mode='w+b', buffer_size=-1,
             os.close(descriptor)
         raise FilesystemError(str(base_exception))
 
-del TemporaryFileWrapperBase
\ No newline at end of file
+# NO DOCS ALLOWED:
+export(DEFAULT_PREFIX,          name='DEFAULT_PREFIX')
+export(DEFAULT_TIMEOUT,         name='DEFAULT_TIMEOUT')
+
+# Assign the modules’ `__all__` and `__dir__` using the exporter:
+__all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
