@@ -2,10 +2,13 @@
 from __future__ import print_function
 
 MOCK_NUMPY = False
-from clu.constants import numpy
+
+from clu.constants.polyfills import numpy, reduce
+from clu.naming import determine_module
+from clu.predicates import allof, isclasstype
 from clu.exporting import Exporter
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 if numpy is None:
@@ -13,9 +16,20 @@ if numpy is None:
     numpy = Mock()
     MOCK_NUMPY = True
 
+# JUST LIKE THE GREEKS
+σ = sum
+Σ = reduce
+
+# Some numpy types are found in subpackages, like e.g. `numpy.ma.core.MaskedArray`;
+# … this predicate function cuts through that nonsense by only looking at the 
+# start of the deduced module string:
+isnumpything = lambda thing: determine_module(thing).lower().startswith('numpy')
+isnumpytype = lambda cls: allof(isclasstype(cls),
+                                isnumpything(cls))
+
 @export
 def isdtype(thing):
-    """ isdtype(thing) → boolean predicate, True if thing is a non-object NumPy dtype """
+    """ isdtype(thing) → boolean predicate, True if thing is a non-object numpy dtype """
     try:
         dt = numpy.dtype(thing)
     except TypeError:
@@ -24,12 +38,12 @@ def isdtype(thing):
 
 @export
 class Clamper(object):
-    __slots__ = ('type', 'info')
     
+    __slots__ = ('type', 'info')
     """ A callable object representing a per-dtype clamp function """
     
     def __init__(self, dtype):
-        """ Initialize a Clamper callable with a NumPy dtype """
+        """ Initialize a Clamper callable with a numpy dtype """
         if not isdtype(dtype):
             raise TypeError("Valid dtype required to initialize a Clamper")
         self.type = dtype
@@ -58,7 +72,7 @@ class Clamper(object):
         return "Clamp a value within the bounds of an %s %s" % (self.bits, self.kind)
     
     def __call__(self, value, a_min=None, a_max=None):
-        """ Clamp a valiue within the bounds of the initializing dtype """
+        """ Clamp a value within the bounds of the initializing dtype """
         a_min = a_min or self.info.min
         a_max = a_max or self.info.max
         return numpy.clip(value, a_min=a_min,
@@ -67,5 +81,14 @@ class Clamper(object):
 clamp = Clamper(dtype=numpy.uint8)
 
 if MOCK_NUMPY is not True:
-    export(clamp, name='clamp')
-    __all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
+    
+    export(σ,               name='σ')
+    export(Σ,               name='Σ')
+    
+    export(isnumpything,    name='isnumpything',    doc="isnumpything(thing) → boolean predicate, True if thing’s qualified module name starts with “numpy”")
+    export(isnumpytype,     name='isnumpytype',     doc="isnumpytype(cls) → boolean predicate, True if thing is from the “numpy” module and is a classtype")
+    
+    export(clamp,           name='clamp')
+    
+    __all__, __dir__ = exporter.all_and_dir()
+    
