@@ -1,16 +1,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-import os
-import pickle
 import warnings
 
-from clu.constants import BASEPATH, BUILTINS, DEBUG, QUALIFIER
-from clu.constants import BadDotpathWarning
+from clu.constants.consts import BUILTINS, DEBUG, QUALIFIER
 from clu.exporting import determine_name, Exporter
-# from clu.predicates import pyattr
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # MODULE SEARCH FUNCTIONS: iterate and search modules, yielding
@@ -67,44 +63,17 @@ def determine_module(thing):
     """ Determine in which module a given thing is ensconced,
         and return that modules’ name as a string.
     """
-    # return pyattr(thing, 'module', 'package') or \
-    #        determine_name(
-    #        thingname_search_by_id(id(thing))[0])
-    return pickle.whichmodule(thing, None)
+    # import pickle
+    # return pickle.whichmodule(thing, None)
+    from clu.exporting import thingname_search_by_id
+    from clu.predicates import pyattr
+    return pyattr(thing, 'module', 'package') or \
+           determine_name(
+           thingname_search_by_id(id(thing))[0])
 
 # QUALIFIED-NAME FUNCTIONS: import by qualified name (like e.g. “yo.dogg.DoggListener”),
 # assess a thing’s qualified name, etc etc.
 
-@export
-def path_to_dotpath(path):
-    """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
-        to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
-        would call a “quick and dirty” fashion.
-        
-        Issues a BadDotpathWarning if the converted path contains
-        dashes – I don’t quite know what to do about something
-        like that besides warn, so erm. There you go.
-    """
-    # Relativize the path to the BASEPATH,
-    # and replace slashes with dots:
-    relpath = os.path.relpath(path, start=BASEPATH)
-    dotpath = relpath.replace(os.path.sep, QUALIFIER)
-    
-    # Trim off any remaining “.py” suffixes,
-    # and extraneous dot-prefixes:
-    if dotpath.endswith('.py'):
-        dotpath = dotpath[:len(dotpath)-3]
-    while dotpath.startswith(QUALIFIER):
-        dotpath = dotpath[1:]
-    
-    # Warn before returning, if the converted path
-    # should contain dashes:
-    if '-' in dotpath:
-        warnings.warn("Dotpath contains dashes: “%s”" % dotpath,
-                      BadDotpathWarning, stacklevel=2)
-    
-    return dotpath
-
 @export
 def dotpath_join(base, *addenda):
     """ Join dotpath elements together as one, á la os.path.join(…) """
