@@ -3,12 +3,12 @@ from __future__ import print_function
 from itertools import chain
 from functools import partial
 
-from clu.constants import PYPY, λ
-from clu.constants import Enum, unicode
+from clu.constants.consts import λ
+from clu.constants.polyfills import unicode
 from clu.enums import alias
 from clu.exporting import Exporter
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # PREDICATE LOGIC: negate(function) will “negate” a boolean predicate function –
@@ -102,6 +102,7 @@ item_search   = lambda itx, *things, default=None: searcher(getitem,   itx, *thi
 @export
 def isenum(cls):
     """ isenum(cls) → boolean predicate, True if cls descends from `Enum`. """
+    from clu.constants.polyfills import Enum
     if not isclasstype(cls):
         return False
     return Enum in cls.__mro__
@@ -150,10 +151,10 @@ class Partial(partial):
         # N.B. The real action seems to happen in partial.__new__(…)
         # Name the Partial instance, as if it’s a lambda-type:
         self.__name__ = self.__qualname__ = λ
-        if PYPY:
+        try:
             super(Partial, self).__init__(*args, **kwargs)
-            return
-        super(Partial, self).__init__()
+        except:
+            super(Partial, self).__init__()
     
     def __repr__(self):
         # Use the lambda_repr equivalent:
