@@ -7,15 +7,15 @@ colorama.init()
 
 import sys
 
-from clu.constants import ENCODING, SEPARATOR_WIDTH
-from clu.constants import Enum, unique, auto
-from clu.exporting import doctrim
-from clu.naming import qualified_name
+from clu.constants.consts import ENCODING, SEPARATOR_WIDTH
+from clu.constants.polyfills import Enum, unique, auto
+from clu.naming import nameof, qualified_name
+from clu.predicates import getpyattr
 from clu.typology import string_types, bytes_types, dict_types
 from clu.enums import alias, AliasingEnumMeta
-from clu.exporting import Exporter
+from clu.exporting import doctrim, Exporter
 
-exporter = Exporter()
+exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 print_separator = lambda filler='-': print(filler * SEPARATOR_WIDTH)
@@ -54,7 +54,8 @@ class ANSI(AliasingEnumMeta):
     def __prepare__(metacls, name, bases, **kwargs):
         """ Remove the “source” class keyword before calling up """
         superkws = dict(kwargs)
-        del superkws['source']
+        if 'source' in superkws:
+            del superkws['source']
         return super(ANSI, metacls).__prepare__(name, bases, **superkws)
     
     def __new__(metacls, name, bases, attributes, **kwargs):
@@ -144,7 +145,7 @@ class ANSI(AliasingEnumMeta):
         if isinstance(specifier, string_types):
             return cls.for_name(specifier)          # Match by name, decoding if necessary
         elif isinstance(specifier, bytes_types):
-            return cls.for_name(str(specifier), encoding=ENCODING)
+            return cls.for_name(str(specifier, encoding=ENCODING))
         raise LookupError("Couldn’t convert specifier to %s: %s" % (cls.__name__,
                                                                     str(specifier)))
     
@@ -323,10 +324,9 @@ class ANSIFormat(ANSIFormatBase):
 def print_ansi(text, color=''):
     """ print_ansi(…) → Print text in ANSI color, using optional inline markup
                         from `colorama` for terminal color-escape delimiters """
-    fmt = ANSIFormat(text=color)
+    fmt = ANSIFormat(color)
     for line in text.splitlines():
-        print(file=sys.__stdout__)
-        print(fmt.render(line), sep='', file=sys.__stdout__)
+        print(fmt.render(line), sep='', end='\n', file=sys.__stdout__)
 
 @export
 def print_ansi_centered(text, color='',
@@ -342,6 +342,21 @@ def print_ansi_centered(text, color='',
     
     print_ansi(f"{aa}{message}{ab}", color=color)
 
+@export
+def ansidoc(*things):
+    """ ansidoc(*things) → Print the docstring value for each thing, in ANSI color """
+    for thing in things:
+        print(file=sys.__stdout__)
+        print_ansi_centered("__doc__ for “%s”" % nameof(thing), color=Text.CYAN)
+        print(file=sys.__stdout__)
+        print_ansi(getpyattr(thing, 'doc', "«unknown»"), color=Text.GRAY)
+        print(file=sys.__stdout__)
+        print_ansi_centered("¡FUCK YEAH!", filler='Ø',
+                                           color=ANSIFormat(text=Text.BLACK,
+                                                            background=Background.CYAN,
+                                                            weight=Weight.DIM))
+        print(file=sys.__stdout__)
+
 @export
 def highlight(code_string, language='json',
                              markup='terminal256',
