@@ -3,26 +3,83 @@ from __future__ import print_function
 
 import pytest
 
+# Currently these need to be defined at the module level,
+# in order for “thingname_search(…)” to find them properly –
+# q.v. “test_exporter_export_lambdas_no_name_provided(…)”
+# definition sub.:
+yo_dogg_lambda = lambda: print("Yo dogg.")
+i_heard_lambda = lambda *wat: print("I heard you like %s" % ", ".join(repr(w) for w in wat))
+
 class TestExporting(object):
     
     """ Run the tests for the clu.exporting module. """
     
+    def test_combine_real_world_exporters_2(self):
+        from clu.predicates import exporter as exporter0
+        from clu.typology import exporter as exporter1
+        from clu.fs.filesystem import exporter as exporter2
+        from clu.exporting import Exporter
+        
+        # Sum the exporters:
+        exporter_sum = Exporter()
+        exporter_sum += exporter0
+        exporter_sum += exporter1
+        exporter_sum += exporter2
+        
+        # Check length:
+        assert len(exporter_sum) == len(exporter0) + len(exporter1) + len(exporter2)
+        
+        # Check key membership:
+        for key in exporter_sum.keys():
+            assert (key in exporter0) or \
+                   (key in exporter1) or \
+                   (key in exporter2)
+        
+        # Check key set heirarchy:
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter0.all_tuple()))
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter1.all_tuple()))
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter2.all_tuple()))
+    
     def test_combine_real_world_exporters_1(self):
         from clu.predicates import exporter as exporter0
         from clu.typology import exporter as exporter1
         from clu.exporting import Exporter
         
+        # Sum the exporters:
         exporter_sum = Exporter()
         exporter_sum += exporter0
         exporter_sum += exporter1
+        
+        # Check length:
         assert len(exporter_sum) == len(exporter0) + len(exporter1)
+        
+        # Check key membership:
+        for key in exporter_sum.keys():
+            assert (key in exporter0) or \
+                   (key in exporter1)
+        
+        # Check key set heirarchy:
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter0.all_tuple()))
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter1.all_tuple()))
     
     def test_combine_real_world_exporters_0(self):
         from clu.predicates import exporter as exporter0
         from clu.typology import exporter as exporter1
         
+        # Sum the exporters:
         exporter_sum = exporter0 + exporter1
+        
+        # Check length:
         assert len(exporter_sum) == len(exporter0) + len(exporter1)
+        
+        # Check key membership:
+        for key in exporter_sum.keys():
+            assert (key in exporter0) or \
+                   (key in exporter1)
+        
+        # Check key set heirarchy:
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter0.all_tuple()))
+        assert frozenset(exporter_sum.all_tuple()).issuperset(frozenset(exporter1.all_tuple()))
     
     def test_exporter_export_constants(self):
         # N.B. the warning checks will *FAIL* for some reason
@@ -53,6 +110,7 @@ class TestExporting(object):
         assert 'I_HEARD' in exporter
         assert 'YO_DOGG_W' in exporter
         assert 'I_HEARD_W' in exporter
+        
         # These don’t work right at non-module-level:
         # assert nameof(YO_DOGG) == 'yo_dogg'
         # assert nameof(I_HEARD) == 'i_heard'
@@ -70,7 +128,7 @@ class TestExporting(object):
         assert 'YO_DOGG_W' in test_dir()
         assert 'I_HEARD_W' in test_dir()
     
-    def _test_exporter_export_lambdas_no_name_provided(self):
+    def test_exporter_export_lambdas_no_name_provided(self):
         # N.B. “thingname_search()” should inspect locals (?!)
         # in order to make this work at non-module-level:
         from clu.exporting import Exporter
@@ -79,32 +137,29 @@ class TestExporting(object):
         exporter = Exporter()
         export = exporter.decorator()
         
-        yo_dogg = lambda: print("Yo dogg.")
-        i_heard = lambda *wat: print("I heard you like %s" % ", ".join(repr(w) for w in wat))
+        export(yo_dogg_lambda,     doc='yo_dogg_lambda() → Prints “Yo dogg.”')
+        export(i_heard_lambda,     doc='i_heard_lambda() → Prints “I heard you like …” with argument reprs')
         
-        export(yo_dogg,     doc='yo_dogg() → Prints “Yo dogg.”')
-        export(i_heard,     doc='i_heard() → Prints “I heard you like …” with argument reprs')
+        assert 'yo_dogg_lambda' in exporter
+        assert 'i_heard_lambda' in exporter
+        assert yo_dogg_lambda.__name__ == 'yo_dogg_lambda'
+        assert i_heard_lambda.__name__ == 'i_heard_lambda'
+        assert yo_dogg_lambda.__qualname__ == 'yo_dogg_lambda'
+        assert i_heard_lambda.__qualname__ == 'i_heard_lambda'
+        assert nameof(yo_dogg_lambda) == 'yo_dogg_lambda'
+        assert nameof(i_heard_lambda) == 'i_heard_lambda'
         
-        assert 'yo_dogg' in exporter
-        assert 'i_heard' in exporter
-        assert yo_dogg.__name__ == 'yo_dogg'
-        assert i_heard.__name__ == 'i_heard'
-        assert yo_dogg.__qualname__ == 'yo_dogg'
-        assert i_heard.__qualname__ == 'i_heard'
-        assert nameof(yo_dogg) == 'yo_dogg'
-        assert nameof(i_heard) == 'i_heard'
-        
-        assert 'yo_dogg() → Prints “Yo dogg.”' in yo_dogg.__doc__
-        assert 'i_heard() → Prints “I heard you like …” with argument reprs' in i_heard.__doc__
+        assert 'yo_dogg_lambda() → Prints “Yo dogg.”' in yo_dogg_lambda.__doc__
+        assert 'i_heard_lambda() → Prints “I heard you like …” with argument reprs' in i_heard_lambda.__doc__
         
         test_all, test_dir = exporter.all_and_dir()
         
         assert len(test_all) == 2
         assert len(test_dir()) == 2
-        assert 'yo_dogg' in test_all
-        assert 'i_heard' in test_all
-        assert 'yo_dogg' in test_dir()
-        assert 'i_heard' in test_dir()
+        assert 'yo_dogg_lambda' in test_all
+        assert 'i_heard_lambda' in test_all
+        assert 'yo_dogg_lambda' in test_dir()
+        assert 'i_heard_lambda' in test_dir()
     
     def test_exporter_export_lambdas(self):
         from clu.exporting import Exporter
