@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from tempfile import gettempdir, NamedTemporaryFile
+from tempfile import gettempdir
 
 import collections.abc
 import contextlib
@@ -13,6 +13,37 @@ class TestFsFilesystem(object):
     
     """ Run the tests for the clu.fs.filesystem module. """
     
+    def test_zip_archive(self, shared_datadir):
+        from clu.fs.filesystem import temporary
+        from clu.typology import isvalidpathlist
+        
+        # Ensure “shared_datadir” has something in it
+        # that we can use:
+        datafiles = tuple(shared_datadir.rglob("*.*"))
+        assert len(datafiles) > 0
+        assert isvalidpathlist(datafiles)
+        
+        # Create a Directory from the fixture-injected pathlib.Path:
+        datadir = Directory(shared_datadir)
+        
+        # Use a temporary file path for the zip archive:
+        tzip = temporary(prefix='test-zip-archive-',
+                         suffix='zip',
+                         randomized=True)
+        
+        try:
+            # Create the zip archive:
+            fzip = datadir.zip_archive(tzip)
+            
+            assert os.path.exists(tzip)
+            assert os.lstat(tzip).st_size > 10000
+            
+            assert os.path.exists(fzip)
+            assert os.path.samefile(tzip, fzip)
+        
+        finally:
+            os.unlink(tzip)
+    
     def test_script_path(self):
         from clu.fs.filesystem import script_path
         
@@ -23,7 +54,7 @@ class TestFsFilesystem(object):
     
     def test_temporary(self):
         from clu.fs.filesystem import temporary, write_to_path
-        from clu.fs.filesystem import FilesystemError
+        from clu.constants.exceptions import FilesystemError
         
         # Prepare the temporary directory:
         d = Directory(gettempdir())
@@ -221,8 +252,9 @@ class TestFsFilesystem(object):
         assert not os.path.exists(p)
     
     def test_ensure_path_is_valid(self):
+        from clu.constants.exceptions import FilesystemError
         from clu.fs.filesystem import ensure_path_is_valid
-        from clu.fs.filesystem import FilesystemError
+        from clu.fs.filesystem import NamedTemporaryFile
         
         with pytest.raises(FilesystemError) as exc:
             ensure_path_is_valid(object())
@@ -258,7 +290,7 @@ class TestFsFilesystem(object):
     
     def test_TemporaryName(self):
         """ Tests for clu.fs.filesystem.TemporaryName """
-        from clu.fs import TemporaryName
+        from clu.fs.filesystem import TemporaryName
         initial = os.getcwd()
         tfp = None
         
@@ -308,7 +340,7 @@ class TestFsFilesystem(object):
     
     def test_wd(self):
         """ Tests for clu.fs.filesystem.wd """
-        from clu.fs import wd
+        from clu.fs.filesystem import wd
         initial = os.getcwd()
         
         with wd() as cwd:
@@ -341,7 +373,7 @@ class TestFsFilesystem(object):
     
     def test_cd(self):
         """ Tests for clu.fs.filesystem.cd """
-        from clu.fs import cd
+        from clu.fs.filesystem import cd
         initial = os.getcwd()
         
         with cd(gettempdir()) as tmp:
@@ -372,7 +404,7 @@ class TestFsFilesystem(object):
     
     def test_TemporaryDirectory(self):
         """ Tests for clu.fs.filesystem.TemporaryDirectory """
-        from clu.fs import TemporaryDirectory
+        from clu.fs.filesystem import TemporaryDirectory
         initial = os.getcwd()
         tdp = None
         
